aboutsummaryrefslogtreecommitdiffstats
path: root/util/miscutil.c
diff options
context:
space:
mode:
authorWerner Koch <[email protected]>2005-07-27 18:10:56 +0000
committerWerner Koch <[email protected]>2005-07-27 18:10:56 +0000
commita1cdf3c75fd5c644607b1877207d1d5b507a5bb9 (patch)
treedb7ed08934f367159a6792990476c0991fa44246 /util/miscutil.c
parentRemoved directories which are only used by the 1.9 branch (diff)
downloadgnupg-a1cdf3c75fd5c644607b1877207d1d5b507a5bb9.tar.gz
gnupg-a1cdf3c75fd5c644607b1877207d1d5b507a5bb9.zip
Converted all m_free to xfree etc.
Diffstat (limited to '')
-rw-r--r--util/miscutil.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/util/miscutil.c b/util/miscutil.c
index 92dde404c..98c2e8d62 100644
--- a/util/miscutil.c
+++ b/util/miscutil.c
@@ -255,7 +255,7 @@ print_utf8_string2 ( FILE *fp, const byte *p, size_t n, int delim )
buf = utf8_to_native ( p, n, delim );
/*(utf8 conversion already does the control character quoting)*/
fputs( buf, fp );
- m_free( buf );
+ xfree( buf );
}
else
print_string( fp, p, n, delim );
@@ -269,7 +269,7 @@ print_utf8_string( FILE *fp, const byte *p, size_t n )
/****************
* This function returns a string which is suitable for printing
* Caller must release it with m_free()
*/
char *
make_printable_string( const byte *p, size_t n, int delim )
@@ -294,7 +294,7 @@ make_printable_string( const byte *p, size_t n, int delim )
p = save_p;
n = save_n;
/* and now make the string */
- d = buffer = m_alloc( buflen );
+ d = buffer = xmalloc( buflen );
for( ; n; n--, p++ ) {
if( *p < 0x20 || (*p >= 0x7f && *p < 0xa0) || *p == delim ||
(delim && *p=='\\')) {
@@ -269,7 +269,7 @@ print_utf8_string( FILE *fp, const byte *p, size_t n )
/****************
* This function returns a string which is suitable for printing
- * Caller must release it with m_free()
+ * Caller must release it with xfree()
*/
char *